@@ -1,4 +1,4 @@
-//@line 39 "/builds/slave/191-lnx-ntly/build/browser/components/feeds/src/FeedConverter.js"
+//@line 39 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/components/feeds/src/FeedConverter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -124,17 +124,7 @@ FeedConverter.prototype = {
    * Records if the feed was sniffed
    */
   _sniffed: false,
-  
-  /**
-   * See nsIStreamConverter.idl
-   */
-  canConvert: function FC_canConvert(sourceType, destinationType) {
-    // We only support one conversion.
-    return destinationType == TYPE_ANY && ((sourceType == TYPE_MAYBE_FEED) ||
-                                           (sourceType == TYPE_MAYBE_VIDEO) ||
-                                           (sourceType == TYPE_MAYBE_AUDIO));
-  },
-  
+
   /**
    * See nsIStreamConverter.idl
    */
@@ -246,18 +236,13 @@ FeedConverter.prototype = {
           getService(Ci.nsIIOService);
       var chromeChannel;
 
-      // show the feed page if it wasn't sniffed and we have a document,
-      // or we have a document, title, and link or id
-      if (result.doc && (!this._sniffed ||
-          (result.doc.title && (result.doc.link || result.doc.id)))) {
+      // If there was no automatic handler, or this was a podcast,
+      // photostream or some other kind of application, show the preview page
+      // if the parser returned a document.
+      if (result.doc) {
 
-        // If there was no automatic handler, or this was a podcast,
-        // photostream or some other kind of application, we must always
-        // show the preview page.
-        
         // Store the result in the result service so that the display
         // page can access it.
-
         feedService.addFeedResult(result);
 
         // Now load the actual XUL document.
@@ -325,7 +310,7 @@ FeedConverter.prototype = {
   /**
    * See nsIRequestObserver.idl
    */
-  onStopRequest: function FC_onStopReqeust(request, context, status) {
+  onStopRequest: function FC_onStopRequest(request, context, status) {
     if (this._processor)
       this._processor.onStopRequest(request, context, status);
   },
@@ -662,7 +647,7 @@ function NSGetModule(cm, file) {
   return Module;
 }
 
-//@line 44 "/builds/slave/191-lnx-ntly/build/toolkit/content/debug.js"
+//@line 44 "/builds/slave/mozilla-1.9.2-linux-nightly/build/toolkit/content/debug.js"
 
 var EXPORTED_SYMBOLS = ["NS_ASSERT"];
 
@@ -744,7 +729,7 @@ function NS_ASSERT(condition, message) {
            getService(Components.interfaces.nsIPromptService);
   ps.alert(source, "Assertion Failed", assertionText + stackText);
 }
-//@line 37 "/builds/slave/191-lnx-ntly/build/browser/components/feeds/src/GenericFactory.js"
+//@line 37 "/builds/slave/mozilla-1.9.2-linux-nightly/build/browser/components/feeds/src/GenericFactory.js"
 
 /**
  * An object implementing nsIFactory that can construct other objects upon
