@@ -718,7 +718,10 @@ pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
+pref("network.IDN.whitelist.lu", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.nu", true);
+pref("network.IDN.whitelist.nz", true);
 pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.pr", true);
 pref("network.IDN.whitelist.se", true);
@@ -728,12 +731,23 @@ pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
 pref("network.IDN.whitelist.vn", true);
 
-// non-ccTLDs
+// IDN ccTLDs
+// ae, UAE, .<Emarat>
+pref("network.IDN.whitelist.xn--mgbaam7a8h", true); 
+// sa, Saudi Arabia, .<al-Saudiah>
+pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true); 
+// ru, Russian Federation, .<RF>
+pref("network.IDN.whitelist.xn--p1ai", true);
+// jo, Jordan, .<Al-Ordon>
+pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+
+// gTLDs
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
 pref("network.IDN.whitelist.museum", true);
 pref("network.IDN.whitelist.org", true);
+pref("network.IDN.whitelist.tel", true);
 
 // NOTE: Before these can be removed, one of bug 414812's tests must be updated
 //       or it will likely fail!  Please CC jwalden+bmo on the bug associated
@@ -813,7 +827,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 835 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 849 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1197,9 +1211,7 @@ pref("dom.max_script_run_time", 10);
 
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
-//
-//  NB: chosen to match dom.max_script_run_time by default
-pref("dom.ipc.plugins.timeoutSecs", 10);
+pref("dom.ipc.plugins.timeoutSecs", 45);
 
 pref("svg.enabled", true);
 pref("svg.smil.enabled", false);
@@ -1236,15 +1248,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1655 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 1667 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2079 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2091 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2282 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2294 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2378 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2390 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2381 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2393 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1514,15 +1526,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2653 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2665 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2721 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2733 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2747 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2759 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2767 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2779 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2775 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2787 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1559,15 +1571,12 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2817 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2829 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
-//@line 2822 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
+//@line 2834 "/builds/slave/mozilla-1.9.2-linux-nightly/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
 // Enable/Disable the orientation API for content
 pref("accelerometer.enabled", true);
-
-// Enable/Disable HTML5 parser
-pref("html5.enable", false);
